@@ -21,8 +21,10 @@ from urllib.parse import urlparse
 import pandas as pd
 from airflow.hooks.base import BaseHook
 from airflow.models import BaseOperator
+from smart_open import open
 
 from astro.sql.table import Table, TempTable, create_table_name
+from astro.utils.cloud_storage_creds import gcs_client, s3fs_creds
 from astro.utils.load_dataframe import move_dataframe_to_sql
 from astro.utils.schema_util import get_schema
 from astro.utils.task_id_helper import get_task_id
@@ -106,26 +108,25 @@ class AgnosticLoadFile(BaseOperator):
             raise ValueError("Invalid path: {}".format(path))
 
         file_type = path.split(".")[-1]
-        storage_options = self._s3fs_creds() if "s3://" in path else None
-        return {"parquet": pd.read_parquet, "csv": pd.read_csv}[file_type](
-            path, storage_options=storage_options
-        )
-
-    def _s3fs_creds(self):
-        # To-do: reuse this method from sql decorator
-        """Structure s3fs credentials from Airflow connection.
-        s3fs enables pandas to write to s3
-        """
-        # To-do: clean-up how S3 creds are passed to s3fs
-        k, v = (
-            os.environ["AIRFLOW__SQL_DECORATOR__CONN_AWS_DEFAULT"]
-            .replace("%2F", "/")
-            .replace("aws://", "")
-            .replace("@", "")
-            .split(":")
-        )
-
-        return {"key": k, "secret": v}
+        transport_params = {
+            "s3": s3fs_creds,
+            "gs": gcs_client,
+            "": lambda: None,
+        }[urlparse(path).scheme]()
+        deserialiser = {
+            "parquet": pd.read_parquet,
+            "csv": pd.read_csv,
+            "json": pd.read_json,
+            "ndjson": pd.read_json,
+        }
+        mode = {"parquet": "rb"}
+        deserialiser_params = {"ndjson": {"lines": True}}
+        with open(
+            path, mode=mode.get(file_type, "r"), transport_params=transport_params
+        ) as stream:
+            return deserialiser[file_type](
+                stream, **deserialiser_params.get(file_type, {})
+            )
 
 
 def load_file(
