@@ -16,14 +16,18 @@ limitations under the License.
 
 import os
 from typing import Optional
+from urllib.parse import urlparse
 
 import boto3
 import pandas as pd
 from airflow.hooks.base import BaseHook
 from airflow.models import BaseOperator, DagRun, TaskInstance
+from google.cloud.storage import Client
+from smart_open import open
 
 from astro.sql.operators.temp_hooks import TempPostgresHook, TempSnowflakeHook
 from astro.sql.table import Table
+from astro.utils.cloud_storage_creds import gcs_client, s3fs_creds
 from astro.utils.task_id_helper import get_task_id
 
 
@@ -86,7 +90,6 @@ class SaveFile(BaseOperator):
             ),
         }.get(conn_type, None)
 
-        eng = input_hook.get_sqlalchemy_engine()
         # Load table from SQL db.
         df = pd.read_sql(
             f"SELECT * FROM {input_table.table_name}",
@@ -102,63 +105,45 @@ class SaveFile(BaseOperator):
             raise FileExistsError
 
     def file_exists(self, output_file_path, output_conn_id=None):
-        if "s3://" in output_file_path:
-
-            bucket_name, object_path = output_file_path.replace("s3://", "").split(
-                "/", 1
-            )
-
-            # Check if object exists in S3.
-            _creds = self._s3fs_creds()
-            s3 = boto3.Session(_creds["key"], _creds["secret"]).resource("s3")
-
-            # Return True if file in S3, else False.
-            try:
-                s3.Object(bucket_name, object_path).load()
+        transport_params = {
+            "s3": s3fs_creds,
+            "gs": gcs_client,
+            "": lambda: None,
+        }[urlparse(output_file_path).scheme]()
+        try:
+            with open(output_file_path, mode="r", transport_params=transport_params):
                 return True
-            except:
-                return False
-
-        else:
-            # Return True if file in local fs, else False.
-            return os.path.isfile(output_file_path)
+        except IOError:
+            return False
 
     def agnostic_write_file(self, df, output_file_path, output_conn_id=None):
         """Write dataframe to csv/parquet files formats
 
         Select output file format based on param output_file_format to class.
         """
-        storage_options = self._s3fs_creds() if "s3://" in output_file_path else None
-        {"csv": df.to_csv, "parquet": df.to_parquet}[self.output_file_format](
-            output_file_path, storage_options=storage_options
-        )
+        transport_params = {
+            "s3": s3fs_creds,
+            "gs": gcs_client,
+            "": lambda: None,
+        }[urlparse(output_file_path).scheme]()
 
-    def _load_dataframe(self, path):
-        """Read file with Pandas.
-
-        Select method based on `file_type` (S3 or local).
-        """
-        file_type = path.split(".")[-1]
-        storage_options = self._s3fs_creds() if "s3://" in path else None
-        return {"parquet": pd.read_parquet, "csv": pd.read_csv}[file_type](
-            path, storage_options=storage_options
-        )
-
-    def _s3fs_creds(self):
-        # To-do: reuse this method from sql decorator
-        """Structure s3fs credentials from Airflow connection.
-        s3fs enables pandas to write to s3
-        """
-        # To-do: clean-up how S3 creds are passed to s3fs
-        k, v = (
-            os.environ["AIRFLOW__SQL_DECORATOR__CONN_AWS_DEFAULT"]
-            .replace("%2F", "/")
-            .replace("aws://", "")
-            .replace("@", "")
-            .split(":")
-        )
-
-        return {"key": k, "secret": v}
+        serialiser = {
+            "parquet": df.to_parquet,
+            "csv": df.to_csv,
+            "json": df.to_json,
+            "ndjson": df.to_json,
+        }
+        serialiser_params = {
+            "csv": {"index": False},
+            "json": {"orient": "records"},
+            "ndjson": {"orient": "records", "lines": True},
+        }
+        with open(
+            output_file_path, mode="wb", transport_params=transport_params
+        ) as stream:
+            serialiser[self.output_file_format](
+                stream, **serialiser_params.get(self.output_file_format, {})
+            )
 
     @staticmethod
     def create_table_name(context):
